# @auto-fold regex /^\s*if/ /^\s*else/ /^\s*def/
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# version 0.3.1
# date 17 jan 2023

__version__ = '0.3.1'
__name__ = 'reddemcee'

__all__ = ['reddemcee', 'reddwrappers']
